Index: channels/chan_agent.c
===================================================================
--- channels/chan_agent.c	(revision 7643)
+++ channels/chan_agent.c	(working copy)
@@ -252,6 +252,7 @@
 static int agent_indicate(struct ast_channel *ast, int condition);
 static int agent_fixup(struct ast_channel *oldchan, struct ast_channel *newchan);
 static struct ast_channel *agent_bridgedchannel(struct ast_channel *chan, struct ast_channel *bridge);
+static void set_agentbycallerid(const char *callerid, const char *agent);
 
 static const struct ast_channel_tech agent_tech = {
 	.type = channeltype,
@@ -466,6 +467,7 @@
 	struct ast_frame *f = NULL;
 	static struct ast_frame null_frame = { AST_FRAME_NULL, };
 	static struct ast_frame answer_frame = { AST_FRAME_CONTROL, AST_CONTROL_ANSWER };
+	char *status;
 	ast_mutex_lock(&p->lock); 
 	CHECK_FORMATS(ast, p);
 	if (p->chan) {
@@ -486,6 +488,26 @@
 			if (!ast_strlen_zero(p->loginchan)) {
 				if (p->chan)
 					ast_log(LOG_DEBUG, "Bridge on '%s' being cleared (2)\n", p->chan->name);
+
+				status = pbx_builtin_getvar_helper(p->chan, "DIALSTATUS");
+				if (status && !strcasecmp(status, "CHANUNAVAIL")) {
+					char agent[AST_MAX_AGENT] = "";
+					long logintime = time(NULL) - p->loginstart;
+					p->loginstart = 0;
+					ast_log(LOG_NOTICE, "Agent '%s' is not available now, auto logoff\n", p->name);
+					manager_event(EVENT_FLAG_AGENT, "Agentcallbacklogoff",
+						      "Agent: %s\r\n"
+						      "Loginchan: %s\r\n"
+						      "Logintime: %ld\r\n"
+						      "Reason: Chanunavail\r\n"
+						      "Uniqueid: %s\r\n",
+						      p->agent, p->loginchan, logintime, ast->uniqueid);
+					snprintf(agent, sizeof(agent), "Agent/%s", p->agent);
+					ast_queue_log("NONE", ast->uniqueid, agent, "AGENTCALLBACKLOGOFF", "%s|%ld|%s", p->loginchan, logintime, "Chanunavail");
+					set_agentbycallerid(p->logincallerid, NULL);
+					p->loginchan[0] = '\0';
+					p->logincallerid[0] = '\0';
+				}
 				ast_hangup(p->chan);
 				if (p->wrapuptime && p->acknowledged)
 					p->lastdisc = ast_tvadd(ast_tvnow(), ast_samp2tv(p->wrapuptime, 1000));
Index: channels/chan_local.c
===================================================================
--- channels/chan_local.c	(revision 7643)
+++ channels/chan_local.c	(working copy)
@@ -405,10 +405,14 @@
 	struct local_pvt *cur, *prev=NULL;
 	struct ast_channel *ochan = NULL;
 	int glaredetect;
+	char *status;
 
 	ast_mutex_lock(&p->lock);
 	isoutbound = IS_OUTBOUND(ast, p);
 	if (isoutbound) {
+		status = pbx_builtin_getvar_helper(p->chan, "DIALSTATUS");
+		if(status)
+			pbx_builtin_setvar_helper(p->owner, "DIALSTATUS", status);
 		p->chan = NULL;
 		p->launchedpbx = 0;
 	} else
Index: doc/manager.txt
===================================================================
--- doc/manager.txt	(revision 7643)
+++ doc/manager.txt	(working copy)
@@ -252,6 +252,7 @@
  Position: <num>		-- Position in Queue
  Queue:				-- Queue name
  Reason:			-- "Autologoff"
+ Reason:			-- "Chanunavail"
  Response: <response>		-- response code, like "200 OK"
 					"Success", "Error", "Follows"
  Restart:			-- "True", "False"
Index: doc/queuelog.txt
===================================================================
--- doc/queuelog.txt	(revision 7643)
+++ doc/queuelog.txt	(working copy)
@@ -32,7 +32,8 @@
 AGENTCALLBACKLOGOFF(exten@context|logintime|reason)
 The callback agent logged off.  The last login extension and context is
 recorded, along with the total time the agent was logged in, and the
-reason for the logoff if it was not a normal logoff (e.g., Autologoff)
+reason for the logoff if it was not a normal logoff 
+(e.g., Autologoff, Chanunavail)
 
 COMPLETEAGENT(holdtime|calltime|origposition)
 The caller was connected to an agent, and the call was terminated normally
